AccessToken class

Represents an access token with an expiration time.

Constructors

AccessToken({required String token, required int expiresOnTimestamp})
const

Properties

expiresOnTimestamp int
The access token's expiration timestamp in milliseconds, UNIX epoch time.
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
token String
The access token returned by the authentication service.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited